@@ -49,7 +49,8 @@ Reference
 from qtpy.QtGui import QPen, QColor, QTextDocument
 from qtpy.QtCore import QRectF, QPointF, QLineF
 
-from guidata.utils import assert_interfaces_valid, update_dataset
+from guidata.utils.misc import assert_interfaces_valid
+from guidata.utils import update_dataset
 
 # Local imports
 from guiqwt.transitional import QwtPlotItem
