@@ -76,32 +76,33 @@ Reference
 
 import os
 import sys
+from math import cos, fabs, pi, sin, sqrt
+
 import numpy as np
-from math import fabs, sqrt, sin, cos, pi
+from guidata.utils.misc import assert_interfaces_valid
+from guidata.utils import update_dataset
+from qtpy.QtCore import QLineF, QPointF, QRectF, Qt
+from qtpy.QtGui import QBrush, QPainter, QPen, QPolygonF, QTransform
 
-from qtpy.QtGui import QPen, QBrush, QPolygonF, QTransform, QPainter
-from qtpy.QtCore import Qt, QRectF, QPointF, QLineF
-
-from guidata.utils import assert_interfaces_valid, update_dataset
-
-# Local imports
-from guiqwt.transitional import QwtPlotItem, QwtSymbol, QwtPlotMarker
+from guiqwt.baseplot import canvas_to_axes
 from guiqwt.config import CONF, _
-from guiqwt.interfaces import IBasePlotItem, IShapeItemType, ISerializableType
-from guiqwt.styles import (
-    MarkerParam,
-    ShapeParam,
-    RangeShapeParam,
-    AxesShapeParam,
-    MARKERSTYLES,
-)
 from guiqwt.geometry import (
+    compute_center,
     vector_norm,
     vector_projection,
     vector_rotation,
-    compute_center,
 )
-from guiqwt.baseplot import canvas_to_axes
+from guiqwt.interfaces import IBasePlotItem, ISerializableType, IShapeItemType
+from guiqwt.styles import (
+    MARKERSTYLES,
+    AxesShapeParam,
+    MarkerParam,
+    RangeShapeParam,
+    ShapeParam,
+)
+
+# Local imports
+from guiqwt.transitional import QwtPlotItem, QwtPlotMarker, QwtSymbol
 
 QT_API = os.environ["QT_API"]
 
@@ -232,6 +233,8 @@ class AbstractShape(QwtPlotItem):
         ctrl: True if <Ctrl> button is being pressed, False otherwise"""
         pt = canvas_to_axes(self, pos)
         self.move_point_to(handle, pt, ctrl)
+        if self.plot():
+            self.plot().SIG_ITEM_HANDLE_MOVED.emit(self)
 
     def move_local_shape(self, old_pos, new_pos):
         """Translate the shape such that old_pos becomes new_pos
@@ -1102,6 +1105,9 @@ class EllipseShape(PolygonShape):
     def switch_to_ellipse(self):
         self.is_ellipse = True
 
+    def switch_to_circle(self):
+        self.is_ellipse = False
+
     def set_xdiameter(self, x0, y0, x1, y1):
         """Set the coordinates of the ellipse's X-axis diameter"""
         xline = QLineF(x0, y0, x1, y1)
@@ -1129,7 +1135,7 @@ class EllipseShape(PolygonShape):
             xline.setLength(self.get_xline().length())
         xline.translate(xline.pointAt(0.5) - xline.p2())
         self.set_points(
-            [(xline.x1(), xline.y1()), (xline.x2(), xline.y2()), (x2, y2), (x3, y3)]
+            [(xline.x2(), xline.y2()), (xline.x1(), xline.y1()), (x2, y2), (x3, y3)]
         )
 
     def get_ydiameter(self):
