@@ -10,7 +10,7 @@ SIFT, the Signal and Image Filtering Tool
 Simple signal and image processing application based on guiqwt and guidata
 """
 
-SHOW = True  # Show test in GUI-based test launcher
+# guitest: show
 
 from qtpy.QtWidgets import (
     QMainWindow,
@@ -54,7 +54,7 @@ from guidata.qthelpers import (
     win32_fix_title_bar_background,
 )
 from guidata.widgets.console import DockableConsole
-from guidata.qtwidgets import DockableWidget, DockableWidgetMixin
+from guidata.widgets.dockable import DockableWidget, DockableWidgetMixin
 from guidata.utils import update_dataset
 
 from guiqwt.config import _
