@@ -89,7 +89,7 @@ The following example add all the existing tools to an `ImageWidget` object
 for testing purpose:
 
 .. literalinclude:: /../guiqwt/tests/image_plot_tools.py
-   :start-after: SHOW
+   :start-after: guitest: show
    :end-before: Workaround for Sphinx v0.6 bug: empty 'end-before' directive
 
 .. image:: /images/screenshots/image_plot_tools.png
@@ -1071,6 +1071,7 @@ class AnnotatedCircleTool(CircleTool):
 class AnnotatedEllipseTool(EllipseTool):
     def create_shape(self):
         annotation = AnnotatedEllipse(0, 0, 1, 1)
+        annotation.shape.switch_to_circle()
         self.set_shape_style(annotation)
         return annotation, 0, 1
 
